@@ -12,21 +12,32 @@ Interface for connecting to and interacting with GSM and CDMA cellular networks.
 
 """
 
+try:
+    from typing import Optional, Tuple, Type
+    from types import TracebackType
+    from adafruit_fona.adafruit_fona import FONA
+except ImportError:
+    pass
+
+__version__ = "0.0.0-auto.0"
+__repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_FONA.git"
+
 # Network types
 NET_GSM = 0x01
 NET_CDMA = 0x02
 
 
 class CELLULAR:
-    """Interface for connecting to and interacting with GSM and CDMA cellular networks."""
+    """Interface for connecting to and interacting with GSM and CDMA cellular networks.
 
-    def __init__(self, fona, apn):
-        """Initializes interface with cellular network.
-        :param adafruit_fona fona: The Adafruit FONA module we are using.
-        :param tuple apn: Tuple containing APN name, (optional) APN username,
-                            and APN password.
+    :param FONA fona: The Adafruit FONA module we are using.
+    :param tuple apn: Tuple containing APN name, (optional) APN username,
+                        and APN password.
+    """
 
-        """
+    def __init__(
+        self, fona: FONA, apn: Tuple[str, Optional[str], Optional[str]]
+    ) -> None:
         self._iface = fona
         self._apn = apn
         self._network_connected = False
@@ -36,24 +47,29 @@ class CELLULAR:
             self._network_type = NET_GSM
             self._iface.gps = True
 
-    def __enter__(self):
+    def __enter__(self) -> "CELLULAR":
         return self
 
-    def __exit__(self, exception_type, exception_value, traceback):
+    def __exit__(
+        self,
+        exception_type: Optional[Type[type]],
+        exception_value: Optional[BaseException],
+        traceback: Optional[TracebackType],
+    ) -> None:
         self.disconnect()
 
     @property
-    def imei(self):
+    def imei(self) -> str:
         """Returns the modem's IEMI number, as a string."""
         return self._iface.iemi
 
     @property
-    def iccid(self):
+    def iccid(self) -> str:
         """Returns the SIM card's ICCID, as a string."""
         return self._iface.iccid
 
     @property
-    def is_attached(self):
+    def is_attached(self) -> bool:
         """Returns if the modem is attached to the network."""
         if self._network_type == NET_GSM:
             if self._iface.gps == 3 and self._iface.network_status == 1:
@@ -70,7 +86,7 @@ class CELLULAR:
             return False
         return True
 
-    def connect(self):
+    def connect(self) -> None:
         """Connect to cellular network."""
         if self._iface.set_gprs(self._apn, True):
             self._network_connected = True
@@ -78,7 +94,7 @@ class CELLULAR:
             # reset context for next connection attempt
             self._iface.set_gprs(self._apn, False)
 
-    def disconnect(self):
+    def disconnect(self) -> None:
         """Disconnect from cellular network."""
         self._iface.set_gprs(self._apn, False)
         self._network_connected = False
